@@ -6,14 +6,14 @@ Type annotations for kafka service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kafka.type_defs import BatchAssociateScramSecretResponseTypeDef
+    from mypy_boto3_kafka.type_defs import BatchAssociateScramSecretRequestTypeDef
 
-    data: BatchAssociateScramSecretResponseTypeDef = {...}
+    data: BatchAssociateScramSecretRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Union
+from typing import IO, Any, Dict, List, Union
 
 from botocore.response import StreamingBody
 
@@ -36,8 +36,10 @@ else:
 
 
 __all__ = (
-    "BatchAssociateScramSecretResponseTypeDef",
-    "BatchDisassociateScramSecretResponseTypeDef",
+    "BatchAssociateScramSecretRequestTypeDef",
+    "BatchAssociateScramSecretResponseResponseTypeDef",
+    "BatchDisassociateScramSecretRequestTypeDef",
+    "BatchDisassociateScramSecretResponseResponseTypeDef",
     "BrokerEBSVolumeInfoTypeDef",
     "BrokerLogsTypeDef",
     "BrokerNodeGroupInfoTypeDef",
@@ -53,34 +55,52 @@ __all__ = (
     "ConfigurationInfoTypeDef",
     "ConfigurationRevisionTypeDef",
     "ConfigurationTypeDef",
-    "CreateClusterResponseTypeDef",
-    "CreateConfigurationResponseTypeDef",
-    "DeleteClusterResponseTypeDef",
-    "DeleteConfigurationResponseTypeDef",
-    "DescribeClusterOperationResponseTypeDef",
-    "DescribeClusterResponseTypeDef",
-    "DescribeConfigurationResponseTypeDef",
-    "DescribeConfigurationRevisionResponseTypeDef",
+    "CreateClusterRequestTypeDef",
+    "CreateClusterResponseResponseTypeDef",
+    "CreateConfigurationRequestTypeDef",
+    "CreateConfigurationResponseResponseTypeDef",
+    "DeleteClusterRequestTypeDef",
+    "DeleteClusterResponseResponseTypeDef",
+    "DeleteConfigurationRequestTypeDef",
+    "DeleteConfigurationResponseResponseTypeDef",
+    "DescribeClusterOperationRequestTypeDef",
+    "DescribeClusterOperationResponseResponseTypeDef",
+    "DescribeClusterRequestTypeDef",
+    "DescribeClusterResponseResponseTypeDef",
+    "DescribeConfigurationRequestTypeDef",
+    "DescribeConfigurationResponseResponseTypeDef",
+    "DescribeConfigurationRevisionRequestTypeDef",
+    "DescribeConfigurationRevisionResponseResponseTypeDef",
     "EBSStorageInfoTypeDef",
     "EncryptionAtRestTypeDef",
     "EncryptionInTransitTypeDef",
     "EncryptionInfoTypeDef",
     "ErrorInfoTypeDef",
     "FirehoseTypeDef",
-    "GetBootstrapBrokersResponseTypeDef",
-    "GetCompatibleKafkaVersionsResponseTypeDef",
+    "GetBootstrapBrokersRequestTypeDef",
+    "GetBootstrapBrokersResponseResponseTypeDef",
+    "GetCompatibleKafkaVersionsRequestTypeDef",
+    "GetCompatibleKafkaVersionsResponseResponseTypeDef",
     "IamTypeDef",
     "JmxExporterInfoTypeDef",
     "JmxExporterTypeDef",
     "KafkaVersionTypeDef",
-    "ListClusterOperationsResponseTypeDef",
-    "ListClustersResponseTypeDef",
-    "ListConfigurationRevisionsResponseTypeDef",
-    "ListConfigurationsResponseTypeDef",
-    "ListKafkaVersionsResponseTypeDef",
-    "ListNodesResponseTypeDef",
-    "ListScramSecretsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
+    "ListClusterOperationsRequestTypeDef",
+    "ListClusterOperationsResponseResponseTypeDef",
+    "ListClustersRequestTypeDef",
+    "ListClustersResponseResponseTypeDef",
+    "ListConfigurationRevisionsRequestTypeDef",
+    "ListConfigurationRevisionsResponseResponseTypeDef",
+    "ListConfigurationsRequestTypeDef",
+    "ListConfigurationsResponseResponseTypeDef",
+    "ListKafkaVersionsRequestTypeDef",
+    "ListKafkaVersionsResponseResponseTypeDef",
+    "ListNodesRequestTypeDef",
+    "ListNodesResponseResponseTypeDef",
+    "ListScramSecretsRequestTypeDef",
+    "ListScramSecretsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
     "LoggingInfoTypeDef",
     "MutableClusterInfoTypeDef",
     "NodeExporterInfoTypeDef",
@@ -91,40 +111,67 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PrometheusInfoTypeDef",
     "PrometheusTypeDef",
-    "RebootBrokerResponseTypeDef",
+    "RebootBrokerRequestTypeDef",
+    "RebootBrokerResponseResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "S3TypeDef",
     "SaslTypeDef",
     "ScramTypeDef",
     "StateInfoTypeDef",
     "StorageInfoTypeDef",
+    "TagResourceRequestTypeDef",
     "TlsTypeDef",
     "UnprocessedScramSecretTypeDef",
-    "UpdateBrokerCountResponseTypeDef",
-    "UpdateBrokerStorageResponseTypeDef",
-    "UpdateBrokerTypeResponseTypeDef",
-    "UpdateClusterConfigurationResponseTypeDef",
-    "UpdateClusterKafkaVersionResponseTypeDef",
-    "UpdateConfigurationResponseTypeDef",
-    "UpdateMonitoringResponseTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateBrokerCountRequestTypeDef",
+    "UpdateBrokerCountResponseResponseTypeDef",
+    "UpdateBrokerStorageRequestTypeDef",
+    "UpdateBrokerStorageResponseResponseTypeDef",
+    "UpdateBrokerTypeRequestTypeDef",
+    "UpdateBrokerTypeResponseResponseTypeDef",
+    "UpdateClusterConfigurationRequestTypeDef",
+    "UpdateClusterConfigurationResponseResponseTypeDef",
+    "UpdateClusterKafkaVersionRequestTypeDef",
+    "UpdateClusterKafkaVersionResponseResponseTypeDef",
+    "UpdateConfigurationRequestTypeDef",
+    "UpdateConfigurationResponseResponseTypeDef",
+    "UpdateMonitoringRequestTypeDef",
+    "UpdateMonitoringResponseResponseTypeDef",
     "ZookeeperNodeInfoTypeDef",
 )
 
-BatchAssociateScramSecretResponseTypeDef = TypedDict(
-    "BatchAssociateScramSecretResponseTypeDef",
+BatchAssociateScramSecretRequestTypeDef = TypedDict(
+    "BatchAssociateScramSecretRequestTypeDef",
     {
         "ClusterArn": str,
-        "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"],
+        "SecretArnList": List[str],
     },
-    total=False,
 )
 
-BatchDisassociateScramSecretResponseTypeDef = TypedDict(
-    "BatchDisassociateScramSecretResponseTypeDef",
+BatchAssociateScramSecretResponseResponseTypeDef = TypedDict(
+    "BatchAssociateScramSecretResponseResponseTypeDef",
     {
         "ClusterArn": str,
         "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchDisassociateScramSecretRequestTypeDef = TypedDict(
+    "BatchDisassociateScramSecretRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "SecretArnList": List[str],
+    },
+)
+
+BatchDisassociateScramSecretResponseResponseTypeDef = TypedDict(
+    "BatchDisassociateScramSecretResponseResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "UnprocessedScramSecrets": List["UnprocessedScramSecretTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 BrokerEBSVolumeInfoTypeDef = TypedDict(
@@ -332,64 +379,166 @@ ConfigurationTypeDef = TypedDict(
     },
 )
 
-CreateClusterResponseTypeDef = TypedDict(
-    "CreateClusterResponseTypeDef",
+_RequiredCreateClusterRequestTypeDef = TypedDict(
+    "_RequiredCreateClusterRequestTypeDef",
     {
-        "ClusterArn": str,
+        "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
         "ClusterName": str,
-        "State": ClusterStateType,
+        "KafkaVersion": str,
+        "NumberOfBrokerNodes": int,
+    },
+)
+_OptionalCreateClusterRequestTypeDef = TypedDict(
+    "_OptionalCreateClusterRequestTypeDef",
+    {
+        "ClientAuthentication": "ClientAuthenticationTypeDef",
+        "ConfigurationInfo": "ConfigurationInfoTypeDef",
+        "EncryptionInfo": "EncryptionInfoTypeDef",
+        "EnhancedMonitoring": EnhancedMonitoringType,
+        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
+        "LoggingInfo": "LoggingInfoTypeDef",
+        "Tags": Dict[str, str],
     },
     total=False,
 )
 
-CreateConfigurationResponseTypeDef = TypedDict(
-    "CreateConfigurationResponseTypeDef",
+
+class CreateClusterRequestTypeDef(
+    _RequiredCreateClusterRequestTypeDef, _OptionalCreateClusterRequestTypeDef
+):
+    pass
+
+
+CreateClusterResponseResponseTypeDef = TypedDict(
+    "CreateClusterResponseResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterName": str,
+        "State": ClusterStateType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateConfigurationRequestTypeDef = TypedDict(
+    "_RequiredCreateConfigurationRequestTypeDef",
+    {
+        "Name": str,
+        "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+    },
+)
+_OptionalCreateConfigurationRequestTypeDef = TypedDict(
+    "_OptionalCreateConfigurationRequestTypeDef",
+    {
+        "Description": str,
+        "KafkaVersions": List[str],
+    },
+    total=False,
+)
+
+
+class CreateConfigurationRequestTypeDef(
+    _RequiredCreateConfigurationRequestTypeDef, _OptionalCreateConfigurationRequestTypeDef
+):
+    pass
+
+
+CreateConfigurationResponseResponseTypeDef = TypedDict(
+    "CreateConfigurationResponseResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
         "State": ConfigurationStateType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDeleteClusterRequestTypeDef = TypedDict(
+    "_RequiredDeleteClusterRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+_OptionalDeleteClusterRequestTypeDef = TypedDict(
+    "_OptionalDeleteClusterRequestTypeDef",
+    {
+        "CurrentVersion": str,
     },
     total=False,
 )
 
-DeleteClusterResponseTypeDef = TypedDict(
-    "DeleteClusterResponseTypeDef",
+
+class DeleteClusterRequestTypeDef(
+    _RequiredDeleteClusterRequestTypeDef, _OptionalDeleteClusterRequestTypeDef
+):
+    pass
+
+
+DeleteClusterResponseResponseTypeDef = TypedDict(
+    "DeleteClusterResponseResponseTypeDef",
     {
         "ClusterArn": str,
         "State": ClusterStateType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DeleteConfigurationResponseTypeDef = TypedDict(
-    "DeleteConfigurationResponseTypeDef",
+DeleteConfigurationRequestTypeDef = TypedDict(
+    "DeleteConfigurationRequestTypeDef",
+    {
+        "Arn": str,
+    },
+)
+
+DeleteConfigurationResponseResponseTypeDef = TypedDict(
+    "DeleteConfigurationResponseResponseTypeDef",
     {
         "Arn": str,
         "State": ConfigurationStateType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeClusterOperationResponseTypeDef = TypedDict(
-    "DescribeClusterOperationResponseTypeDef",
+DescribeClusterOperationRequestTypeDef = TypedDict(
+    "DescribeClusterOperationRequestTypeDef",
+    {
+        "ClusterOperationArn": str,
+    },
+)
+
+DescribeClusterOperationResponseResponseTypeDef = TypedDict(
+    "DescribeClusterOperationResponseResponseTypeDef",
     {
         "ClusterOperationInfo": "ClusterOperationInfoTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeClusterResponseTypeDef = TypedDict(
-    "DescribeClusterResponseTypeDef",
+DescribeClusterRequestTypeDef = TypedDict(
+    "DescribeClusterRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+
+DescribeClusterResponseResponseTypeDef = TypedDict(
+    "DescribeClusterResponseResponseTypeDef",
     {
         "ClusterInfo": "ClusterInfoTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeConfigurationResponseTypeDef = TypedDict(
-    "DescribeConfigurationResponseTypeDef",
+DescribeConfigurationRequestTypeDef = TypedDict(
+    "DescribeConfigurationRequestTypeDef",
+    {
+        "Arn": str,
+    },
+)
+
+DescribeConfigurationResponseResponseTypeDef = TypedDict(
+    "DescribeConfigurationResponseResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
@@ -398,20 +547,28 @@ DescribeConfigurationResponseTypeDef = TypedDict(
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
         "State": ConfigurationStateType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeConfigurationRevisionResponseTypeDef = TypedDict(
-    "DescribeConfigurationRevisionResponseTypeDef",
+DescribeConfigurationRevisionRequestTypeDef = TypedDict(
+    "DescribeConfigurationRevisionRequestTypeDef",
+    {
+        "Arn": str,
+        "Revision": int,
+    },
+)
+
+DescribeConfigurationRevisionResponseResponseTypeDef = TypedDict(
+    "DescribeConfigurationRevisionResponseResponseTypeDef",
     {
         "Arn": str,
         "CreationTime": datetime,
         "Description": str,
         "Revision": int,
-        "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+        "ServerProperties": bytes,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EBSStorageInfoTypeDef = TypedDict(
@@ -475,23 +632,38 @@ class FirehoseTypeDef(_RequiredFirehoseTypeDef, _OptionalFirehoseTypeDef):
     pass
 
 
-GetBootstrapBrokersResponseTypeDef = TypedDict(
-    "GetBootstrapBrokersResponseTypeDef",
+GetBootstrapBrokersRequestTypeDef = TypedDict(
+    "GetBootstrapBrokersRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+
+GetBootstrapBrokersResponseResponseTypeDef = TypedDict(
+    "GetBootstrapBrokersResponseResponseTypeDef",
     {
         "BootstrapBrokerString": str,
         "BootstrapBrokerStringTls": str,
         "BootstrapBrokerStringSaslScram": str,
         "BootstrapBrokerStringSaslIam": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetCompatibleKafkaVersionsRequestTypeDef = TypedDict(
+    "GetCompatibleKafkaVersionsRequestTypeDef",
+    {
+        "ClusterArn": str,
     },
     total=False,
 )
 
-GetCompatibleKafkaVersionsResponseTypeDef = TypedDict(
-    "GetCompatibleKafkaVersionsResponseTypeDef",
+GetCompatibleKafkaVersionsResponseResponseTypeDef = TypedDict(
+    "GetCompatibleKafkaVersionsResponseResponseTypeDef",
     {
         "CompatibleKafkaVersions": List["CompatibleKafkaVersionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 IamTypeDef = TypedDict(
@@ -525,75 +697,197 @@ KafkaVersionTypeDef = TypedDict(
     total=False,
 )
 
-ListClusterOperationsResponseTypeDef = TypedDict(
-    "ListClusterOperationsResponseTypeDef",
+_RequiredListClusterOperationsRequestTypeDef = TypedDict(
+    "_RequiredListClusterOperationsRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+_OptionalListClusterOperationsRequestTypeDef = TypedDict(
+    "_OptionalListClusterOperationsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListClusterOperationsRequestTypeDef(
+    _RequiredListClusterOperationsRequestTypeDef, _OptionalListClusterOperationsRequestTypeDef
+):
+    pass
+
+
+ListClusterOperationsResponseResponseTypeDef = TypedDict(
+    "ListClusterOperationsResponseResponseTypeDef",
     {
         "ClusterOperationInfoList": List["ClusterOperationInfoTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListClustersRequestTypeDef = TypedDict(
+    "ListClustersRequestTypeDef",
+    {
+        "ClusterNameFilter": str,
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListClustersResponseTypeDef = TypedDict(
-    "ListClustersResponseTypeDef",
+ListClustersResponseResponseTypeDef = TypedDict(
+    "ListClustersResponseResponseTypeDef",
     {
         "ClusterInfoList": List["ClusterInfoTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListConfigurationRevisionsRequestTypeDef = TypedDict(
+    "_RequiredListConfigurationRevisionsRequestTypeDef",
+    {
+        "Arn": str,
+    },
+)
+_OptionalListConfigurationRevisionsRequestTypeDef = TypedDict(
+    "_OptionalListConfigurationRevisionsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListConfigurationRevisionsResponseTypeDef = TypedDict(
-    "ListConfigurationRevisionsResponseTypeDef",
+
+class ListConfigurationRevisionsRequestTypeDef(
+    _RequiredListConfigurationRevisionsRequestTypeDef,
+    _OptionalListConfigurationRevisionsRequestTypeDef,
+):
+    pass
+
+
+ListConfigurationRevisionsResponseResponseTypeDef = TypedDict(
+    "ListConfigurationRevisionsResponseResponseTypeDef",
     {
         "NextToken": str,
         "Revisions": List["ConfigurationRevisionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListConfigurationsRequestTypeDef = TypedDict(
+    "ListConfigurationsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListConfigurationsResponseTypeDef = TypedDict(
-    "ListConfigurationsResponseTypeDef",
+ListConfigurationsResponseResponseTypeDef = TypedDict(
+    "ListConfigurationsResponseResponseTypeDef",
     {
         "Configurations": List["ConfigurationTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListKafkaVersionsRequestTypeDef = TypedDict(
+    "ListKafkaVersionsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListKafkaVersionsResponseTypeDef = TypedDict(
-    "ListKafkaVersionsResponseTypeDef",
+ListKafkaVersionsResponseResponseTypeDef = TypedDict(
+    "ListKafkaVersionsResponseResponseTypeDef",
     {
         "KafkaVersions": List["KafkaVersionTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListNodesRequestTypeDef = TypedDict(
+    "_RequiredListNodesRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+_OptionalListNodesRequestTypeDef = TypedDict(
+    "_OptionalListNodesRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListNodesResponseTypeDef = TypedDict(
-    "ListNodesResponseTypeDef",
+
+class ListNodesRequestTypeDef(_RequiredListNodesRequestTypeDef, _OptionalListNodesRequestTypeDef):
+    pass
+
+
+ListNodesResponseResponseTypeDef = TypedDict(
+    "ListNodesResponseResponseTypeDef",
     {
         "NextToken": str,
         "NodeInfoList": List["NodeInfoTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListScramSecretsRequestTypeDef = TypedDict(
+    "_RequiredListScramSecretsRequestTypeDef",
+    {
+        "ClusterArn": str,
+    },
+)
+_OptionalListScramSecretsRequestTypeDef = TypedDict(
+    "_OptionalListScramSecretsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
-ListScramSecretsResponseTypeDef = TypedDict(
-    "ListScramSecretsResponseTypeDef",
+
+class ListScramSecretsRequestTypeDef(
+    _RequiredListScramSecretsRequestTypeDef, _OptionalListScramSecretsRequestTypeDef
+):
+    pass
+
+
+ListScramSecretsResponseResponseTypeDef = TypedDict(
+    "ListScramSecretsResponseResponseTypeDef",
     {
         "NextToken": str,
         "SecretArnList": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LoggingInfoTypeDef = TypedDict(
@@ -687,13 +981,32 @@ PrometheusTypeDef = TypedDict(
     total=False,
 )
 
-RebootBrokerResponseTypeDef = TypedDict(
-    "RebootBrokerResponseTypeDef",
+RebootBrokerRequestTypeDef = TypedDict(
+    "RebootBrokerRequestTypeDef",
+    {
+        "BrokerIds": List[str],
+        "ClusterArn": str,
+    },
+)
+
+RebootBrokerResponseResponseTypeDef = TypedDict(
+    "RebootBrokerResponseResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
     },
-    total=False,
 )
 
 _RequiredS3TypeDef = TypedDict(
@@ -750,6 +1063,14 @@ StorageInfoTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
 TlsTypeDef = TypedDict(
     "TlsTypeDef",
     {
@@ -768,67 +1089,181 @@ UnprocessedScramSecretTypeDef = TypedDict(
     total=False,
 )
 
-UpdateBrokerCountResponseTypeDef = TypedDict(
-    "UpdateBrokerCountResponseTypeDef",
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateBrokerCountRequestTypeDef = TypedDict(
+    "UpdateBrokerCountRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+        "TargetNumberOfBrokerNodes": int,
+    },
+)
+
+UpdateBrokerCountResponseResponseTypeDef = TypedDict(
+    "UpdateBrokerCountResponseResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateBrokerStorageRequestTypeDef = TypedDict(
+    "UpdateBrokerStorageRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+        "TargetBrokerEBSVolumeInfo": List["BrokerEBSVolumeInfoTypeDef"],
+    },
+)
+
+UpdateBrokerStorageResponseResponseTypeDef = TypedDict(
+    "UpdateBrokerStorageResponseResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateBrokerTypeRequestTypeDef = TypedDict(
+    "UpdateBrokerTypeRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+        "TargetInstanceType": str,
+    },
+)
+
+UpdateBrokerTypeResponseResponseTypeDef = TypedDict(
+    "UpdateBrokerTypeResponseResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+UpdateClusterConfigurationRequestTypeDef = TypedDict(
+    "UpdateClusterConfigurationRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "ConfigurationInfo": "ConfigurationInfoTypeDef",
+        "CurrentVersion": str,
+    },
+)
+
+UpdateClusterConfigurationResponseResponseTypeDef = TypedDict(
+    "UpdateClusterConfigurationResponseResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateClusterKafkaVersionRequestTypeDef = TypedDict(
+    "_RequiredUpdateClusterKafkaVersionRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+        "TargetKafkaVersion": str,
+    },
+)
+_OptionalUpdateClusterKafkaVersionRequestTypeDef = TypedDict(
+    "_OptionalUpdateClusterKafkaVersionRequestTypeDef",
+    {
+        "ConfigurationInfo": "ConfigurationInfoTypeDef",
     },
     total=False,
 )
 
-UpdateBrokerStorageResponseTypeDef = TypedDict(
-    "UpdateBrokerStorageResponseTypeDef",
+
+class UpdateClusterKafkaVersionRequestTypeDef(
+    _RequiredUpdateClusterKafkaVersionRequestTypeDef,
+    _OptionalUpdateClusterKafkaVersionRequestTypeDef,
+):
+    pass
+
+
+UpdateClusterKafkaVersionResponseResponseTypeDef = TypedDict(
+    "UpdateClusterKafkaVersionResponseResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateConfigurationRequestTypeDef = TypedDict(
+    "_RequiredUpdateConfigurationRequestTypeDef",
+    {
+        "Arn": str,
+        "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+    },
+)
+_OptionalUpdateConfigurationRequestTypeDef = TypedDict(
+    "_OptionalUpdateConfigurationRequestTypeDef",
+    {
+        "Description": str,
     },
     total=False,
 )
 
-UpdateBrokerTypeResponseTypeDef = TypedDict(
-    "UpdateBrokerTypeResponseTypeDef",
-    {
-        "ClusterArn": str,
-        "ClusterOperationArn": str,
-    },
-    total=False,
-)
 
-UpdateClusterConfigurationResponseTypeDef = TypedDict(
-    "UpdateClusterConfigurationResponseTypeDef",
-    {
-        "ClusterArn": str,
-        "ClusterOperationArn": str,
-    },
-    total=False,
-)
+class UpdateConfigurationRequestTypeDef(
+    _RequiredUpdateConfigurationRequestTypeDef, _OptionalUpdateConfigurationRequestTypeDef
+):
+    pass
 
-UpdateClusterKafkaVersionResponseTypeDef = TypedDict(
-    "UpdateClusterKafkaVersionResponseTypeDef",
-    {
-        "ClusterArn": str,
-        "ClusterOperationArn": str,
-    },
-    total=False,
-)
 
-UpdateConfigurationResponseTypeDef = TypedDict(
-    "UpdateConfigurationResponseTypeDef",
+UpdateConfigurationResponseResponseTypeDef = TypedDict(
+    "UpdateConfigurationResponseResponseTypeDef",
     {
         "Arn": str,
         "LatestRevision": "ConfigurationRevisionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateMonitoringRequestTypeDef = TypedDict(
+    "_RequiredUpdateMonitoringRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+    },
+)
+_OptionalUpdateMonitoringRequestTypeDef = TypedDict(
+    "_OptionalUpdateMonitoringRequestTypeDef",
+    {
+        "EnhancedMonitoring": EnhancedMonitoringType,
+        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
+        "LoggingInfo": "LoggingInfoTypeDef",
     },
     total=False,
 )
 
-UpdateMonitoringResponseTypeDef = TypedDict(
-    "UpdateMonitoringResponseTypeDef",
+
+class UpdateMonitoringRequestTypeDef(
+    _RequiredUpdateMonitoringRequestTypeDef, _OptionalUpdateMonitoringRequestTypeDef
+):
+    pass
+
+
+UpdateMonitoringResponseResponseTypeDef = TypedDict(
+    "UpdateMonitoringResponseResponseTypeDef",
     {
         "ClusterArn": str,
         "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ZookeeperNodeInfoTypeDef = TypedDict(
